@@ -8,6 +8,7 @@
 #include <morphio/types.h>
 #include <morphio/version.h>
 
+#include "../../include/morphio/enums.h"
 #include "bind_enums.h"
 
 namespace py = pybind11;
@@ -20,6 +21,7 @@ void bind_misc(py::module& m) {
           "Set the maximum number of warnings to be printed on screen\n"
           "0 will print no warning\n"
           "-1 will print them all");
+    m.def("set_raise_warnings", &morphio::set_raise_warnings, "Whether to raise warning as errors");
     m.def("set_ignored_warning",
           static_cast<void (*)(morphio::Warning, bool)>(&morphio::set_ignored_warning),
           "Ignore/Unignore a specific warning message",
@@ -55,6 +57,12 @@ void bind_misc(py::module& m) {
         .value("axon", morphio::enums::SectionType::SECTION_AXON)
         .value("basal_dendrite", morphio::enums::SectionType::SECTION_DENDRITE)
         .value("apical_dendrite", morphio::enums::SectionType::SECTION_APICAL_DENDRITE)
+        .value("custom5", morphio::enums::SectionType::SECTION_CUSTOM_5)
+        .value("custom6", morphio::enums::SectionType::SECTION_CUSTOM_6)
+        .value("custom7", morphio::enums::SectionType::SECTION_CUSTOM_7)
+        .value("custom8", morphio::enums::SectionType::SECTION_CUSTOM_8)
+        .value("custom9", morphio::enums::SectionType::SECTION_CUSTOM_9)
+        .value("custom10", morphio::enums::SectionType::SECTION_CUSTOM_10)
         // .value("glia_process", morphio::enums::SectionType::SECTION_GLIA_PROCESS)
         // .value("glia_endfoot", morphio::enums::SectionType::SECTION_GLIA_ENDFOOT)
         .export_values();
