@@ -131,9 +131,9 @@ void bind_mutable_module(py::module& m) {
 
         .def_property_readonly("version", &morphio::mut::Morphology::version, "Returns the version")
 
-        .def("sanitize",
+        .def("remove_unifurcations",
              static_cast<void (morphio::mut::Morphology::*) ()>(
-                 &morphio::mut::Morphology::sanitize),
+                 &morphio::mut::Morphology::removeUnifurcations),
              "Fixes the morphology single child sections and issues warnings"
              "if the section starts and ends are inconsistent")
 
@@ -435,7 +435,7 @@ void bind_mutable_module(py::module& m) {
 
         .def("append_section",
              static_cast<std::shared_ptr<morphio::mut::Section> (
-                 morphio::mut::Section::*)(const std::shared_ptr<morphio::mut::Section>&, bool)>(
+                 morphio::mut::Section::*)(std::shared_ptr<morphio::mut::Section>, bool)>(
                  &morphio::mut::Section::appendSection),
              "Append the existing mutable Section to this section\n"
              "If recursive == true, all descendent will be appended as well",
