@@ -4,6 +4,7 @@
 
 namespace morphio {
 static int MORPHIO_MAX_N_WARNINGS = 100;
+static bool MORPHIO_RAISE_WARNINGS = false;
 
 /**
    Controls the maximum number of warning to be printed on screen
@@ -14,6 +15,13 @@ void set_maximum_warnings(int n_warnings) {
     MORPHIO_MAX_N_WARNINGS = n_warnings;
 }
 
+/**
+   Whether to raise warning as errors
+**/
+void set_raise_warnings(bool is_raise) {
+    MORPHIO_RAISE_WARNINGS = is_raise;
+}
+
 void set_ignored_warning(Warning warning, bool ignore) {
     if (ignore)
         readers::_ignoredWarnings.insert(warning);
@@ -28,9 +36,13 @@ void set_ignored_warning(const std::vector<Warning>& warnings, bool ignore) {
 
 void printError(Warning warning, const std::string& msg) {
     static int error = 0;
+
     if (readers::ErrorMessages::isIgnored(warning) || MORPHIO_MAX_N_WARNINGS == 0)
         return;
 
+    if (MORPHIO_RAISE_WARNINGS)
+        throw MorphioError(msg);
+
     if (MORPHIO_MAX_N_WARNINGS < 0 || error <= MORPHIO_MAX_N_WARNINGS) {
         std::cerr << msg << '\n';
         if (error == MORPHIO_MAX_N_WARNINGS) {
