@@ -5,8 +5,8 @@ from nose import tools as nt
 from nose.tools import assert_equal, assert_raises
 from numpy.testing import assert_array_equal
 
-from morphio import (Morphology, RawDataError, SectionType, SomaError, SomaType,
-                     ostream_redirect, set_maximum_warnings, set_ignored_warning, Warning)
+from morphio import (Morphology, RawDataError, SectionType, SomaError, MorphioError, SomaType,
+                     ostream_redirect, set_maximum_warnings, set_raise_warnings, set_ignored_warning, Warning)
 from . utils import (_test_swc_exception, assert_substring, assert_string_equal, captured_output,
                    strip_color_codes, tmp_swc_file, ignored_warning)
 
@@ -76,6 +76,18 @@ def test_read_simple():
     assert_array_equal(simple.root_sections[1].points, [[0, 0, 0], [0, -4, 0]])
 
 
+def test_set_raise_warnings():
+    try:
+        set_raise_warnings(True)
+        with assert_raises(MorphioError) as e:
+            Morphology(os.path.join(_path, 'disconnected_neurite.swc'))
+        assert_substring(
+            'Warning: found a disconnected neurite',
+            strip_color_codes(str(e.exception)))
+    finally:
+        set_raise_warnings(False)
+
+
 def test_repeated_id():
     _test_swc_exception('''# A simple neuron with a repeated id
                        1 1 0 0 1 0.5 -1
@@ -259,12 +271,20 @@ def test_soma_type():
 
     with captured_output() as (_, err):
         with ostream_redirect(stdout=True, stderr=True):
-
             with tmp_swc_file('''1 1 0  0 0 3.0 -1
                                  2 1 1 -3 0 3.0  1
                                  3 1 0  0 0 3.0  1 # PID is 1''') as tmp_file:
                 assert_equal(Morphology(tmp_file.name).soma_type,
                              SomaType.SOMA_NEUROMORPHO_THREE_POINT_CYLINDERS)
+                assert_string_equal('', err.getvalue())
+
+    with captured_output() as (_, err):
+        with ostream_redirect(stdout=True, stderr=True):
+            with tmp_swc_file('''1 1 0  0 0 3.0 -1
+                                 2 1 0 -3 0 3.0  1
+                                 3 1 0  0 0 3.0  1 # PID is 1''') as tmp_file:
+                assert_equal(Morphology(tmp_file.name).soma_type,
+                             SomaType.SOMA_NEUROMORPHO_THREE_POINT_CYLINDERS)
                 assert_string_equal(
                     '''{}:0:warning
                        Warning: the soma does not conform the three point soma spec
@@ -275,7 +295,7 @@ def test_soma_type():
 
                        Got:
                        1 1 0 0 0 3 -1
-                       2 1 1.000000 (exp. 0.000000) -3.000000 0.000000 3.000000 1
+                       2 1 0.000000 -3.000000 0.000000 3.000000 1
                        3 1 0.000000 0.000000 (exp. 3.000000) 0.000000 3.000000 1'''.format(tmp_file.name),
                     err.getvalue(),
 				)
@@ -396,7 +416,7 @@ def test_read_duplicate():
 def test_unsupported_section_type():
     with tmp_swc_file('''1 1 0 4 0 3.0 -1
                          2 3 0 0 2 0.5 1
-                         3 5 0 0 3 0.5 2  # <-- 5 is unsupported section type
+                         3 -1 0 0 3 0.5 2  # <-- -1 is unsupported section type
                          ''') as tmp_file:
 
         with assert_raises(RawDataError) as obj:
@@ -406,7 +426,21 @@ def test_unsupported_section_type():
         strip_color_codes(str(obj.exception)))
 
     assert_substring(
-        'Unsupported section type: 5',
+        'Unsupported section type: -1',
+        strip_color_codes(str(obj.exception)))
+    with tmp_swc_file('''1 1 0 4 0 3.0 -1
+                         2 3 0 0 2 0.5 1
+                         3 11 0 0 3 0.5 2  # <-- 11 is unsupported section type
+                         ''') as tmp_file:
+
+        with assert_raises(RawDataError) as obj:
+            Morphology(tmp_file.name)
+    assert_substring(
+        '.swc:3:error',
+        strip_color_codes(str(obj.exception)))
+
+    assert_substring(
+        'Unsupported section type: 11',
         strip_color_codes(str(obj.exception)))
 
 def test_root_node_split():
